<template>
  <div class="p-4 pb-5 mb-5">
    <div class="row">
      <div class="col-12 d-flex align-items-center mb-3">
        <div class="orange-line"></div>
        <h4 class="fw-bold text-dark mb-0 me-3">{{ t("account.advertise.title") }}</h4>
      </div>
    </div>

    <template v-if="data.advertises.length > 0">
      <div class="row mt-3 mb-lg-0">
        <div v-for="(advertise, index) in data.advertises" :key="index" class="col-12 mb-2">
          <user-advertise :data="advertise" :step="true"/>
        </div>
      </div>
    </template>
    <template v-else>
      <template v-if="data.loaded">
        <div class="row mt-5">
          <div class="col-12">
            <div class="d-flex align-items-center justify-content-center flex-column py-1">
              <i class="icon icon-regular-papers-text text-muted" style="font-size: 3rem;"></i>
              <h5 class="mt-3 text-center text-secondary">{{ t("account.advertise.empty.title") }}</h5>
              <p class="text-muted text-center">{{ t("account.advertise.empty.description") }}</p>
            </div>
          </div>
        </div>
      </template>
    </template>

    <!-- شیمِر لودینگ -->
    <template v-if="!data.loaded">
      <loaded-account-advertise/>
    </template>

    <!-- افزودن آگهی -->
    <div class="col-12 my-2">
      <div class="card h-100 border-dashed hover-effect">
        <nuxt-link to="/account/advertise/create"
                   class="card-body d-flex flex-column justify-content-center align-items-center text-center p-4">
          <div class="add-icon py-3">
            <i class="icon icon-regular-plus text-default fs-1"></i>
          </div>
          <h6 class="text-muted mb-3">{{ t('account.advertise.add_advertise') }}</h6>
        </nuxt-link>
      </div>
    </div>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n'
import {useRoute, useRouter} from 'vue-router'
import {useCookie} from 'nuxt/app'
import {onMounted, onBeforeUnmount, reactive} from 'vue'

definePageMeta({
  layout: "default",
  middleware: ['auth'],
});

// Variable
const {t} = useI18n();
const route = useRoute();
const router = useRouter();
const {$api} = useNuxtApp();

const token = useCookie('token').value

// Data
const data = reactive({
  loaded: false,
  filter: {
    page: 1
  },
  advertises: [],
  meta: {
    last_page: ""
  },
});

// Actions
const getData = async () => {
  data.loaded = false;
  await $api.post("/user/advertise", data.filter).then((value) => {
    data.advertises.push(...value.data.data);

    data.meta = value.data.meta;

    router.push({
      path: route.fullPath,
      query: data.filter
    });

    setTimeout(() => {
      data.loaded = true;
    },500);
  });
}

const isBottomOfPage = () => {
  return window.innerHeight + window.scrollY >= document.documentElement.scrollHeight - 500;
}

const handleScroll = () => {
  if (isBottomOfPage() && data.loaded && data.filter.page < data.meta.last_page) {
    data.filter.page++;
    getData();
  }
}

// Life Cycle
onMounted(() => {
  getData()
  window.addEventListener('scroll', handleScroll)
});

onBeforeUnmount(() => {
  window.removeEventListener('scroll', handleScroll)
});

</script>

<style scoped>

</style>
